# Pulser

A framework for interacting with [Pasqal][pasqal] devices at the **pulse** level.

Pulser is a library that allows for writing sequences of pulses representing the
behaviour of some Pasqal processor prototypes.


## Installation

To install Pulser from PyPI:

```bash
pip install pulser
```

[pasqal]: https://pasqal.io/
